# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.Utilities

class CsvFileTraceListener(
    System.IDisposable, System.Diagnostics.TextWriterTraceListener
):  # Class
    @overload
    def __init__(self, stream: System.IO.Stream, name: str) -> None: ...
    @overload
    def __init__(self, stream: System.IO.Stream) -> None: ...
    @overload
    def __init__(self, fileName: str, name: str) -> None: ...
    @overload
    def __init__(self, fileName: str) -> None: ...
    @overload
    def __init__(self, writer: System.IO.TextWriter, name: str) -> None: ...
    @overload
    def __init__(self, writer: System.IO.TextWriter) -> None: ...
    @overload
    def Write(self, anObject: Any) -> None: ...
    @overload
    def Write(self, message: str) -> None: ...
    @overload
    def Write(self, anObject: Any, category: str) -> None: ...
    @overload
    def Write(self, message: str, category: str) -> None: ...
    @overload
    def WriteLine(self, anObject: Any) -> None: ...
    @overload
    def WriteLine(self, message: str) -> None: ...
    @overload
    def WriteLine(self, anObject: Any, category: str) -> None: ...
    @overload
    def WriteLine(self, message: str, category: str) -> None: ...

class MemoryTraceListener(
    System.IDisposable, System.Diagnostics.TraceListener
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, initData: str) -> None: ...
    @overload
    def __init__(self, initData: str, name: str) -> None: ...

    DEFAULT_LOG_FILE_NAME: str = ...  # static # readonly
    DEFAULT_LOG_SIZE: int = ...  # static # readonly
    MAX_LOG_SIZE: int = ...  # static # readonly
    MEGABYTE: int = ...  # static # readonly
    MIN_LOG_SIZE: int = ...  # static # readonly

    LastWrittenCompressedLogFile: str  # static # readonly
    LastWrittenLogFile: str  # static # readonly
    LogFileName: str
    LogSize: int

    @staticmethod
    def IsActive() -> bool: ...
    @overload
    def Write(self, anObject: Any) -> None: ...
    @overload
    def Write(self, message: str) -> None: ...
    @overload
    def Write(self, anObject: Any, category: str) -> None: ...
    @overload
    def Write(self, message: str, category: str) -> None: ...
    @overload
    def WriteLine(self, anObject: Any) -> None: ...
    @overload
    def WriteLine(self, message: str) -> None: ...
    @overload
    def WriteLine(self, anObject: Any, category: str) -> None: ...
    @overload
    def WriteLine(self, message: str, category: str) -> None: ...
    @staticmethod
    def DumpCompressedLog() -> None: ...
    @staticmethod
    def DumpLog() -> None: ...
    def Close(self) -> None: ...

class TraceListenerUtilities:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def GetLogPath(fileName: str) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Models import (
    IAppCommandContext,
    ICalibrationRange,
    ICalibrationRangeItem,
    ICalibrationRangeViewModel,
    ICalibrationViewModel,
    ICompoundsViewModel,
    IDynamicCalibrationSetupModel,
    IIonGroupGraphicsViewModel,
    IIonGroupItem,
    IIonGroupPlotSeries,
    IIonGroupViewModel,
    IQualifiersViewModel,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.ViewModels

class CalibrationRangeItem(ICalibrationRangeItem):  # Class
    def __init__(self, calRange: ICalibrationRange) -> None: ...

    CalibrationRangeID: int  # readonly
    MaxConcentration: Optional[float]  # readonly
    MinConcentration: Optional[float]  # readonly
    QualifierIonGroupIDs: List[int]  # readonly
    TargetCompoundID: int  # readonly
    TargetIonGroupID: Optional[int]  # readonly

class CalibrationRangeViewModel(
    System.Windows.DependencyObject, System.IDisposable, ICalibrationRangeViewModel
):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...

    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly

    def Dispose(self) -> None: ...

class CalibrationViewModel(
    System.IDisposable,
    ICalibrationViewModel,
    System.Windows.DependencyObject,
    System.Collections.Generic.IComparer[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ],
):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...

    CalibrationProperty: System.Windows.DependencyProperty  # static

    Calibration: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow
    ]
    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly
    SortAscending: bool  # readonly
    SortedColumn: str  # readonly

    def SetSort(self, sortColumn: str, sortAscending: bool) -> None: ...
    def Dispose(self) -> None: ...
    def Compare(
        self,
        o1: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow,
        o2: Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.CalibrationRow,
    ) -> int: ...

class CompoundsViewModel(
    ICompoundsViewModel, System.Windows.DependencyObject, System.IDisposable
):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...

    TargetCompoundProperty: System.Windows.DependencyProperty  # static

    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly
    TargetCompound: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.QuantitationDataSet.TargetCompoundDataTable
    )

    def Dispose(self) -> None: ...

class DynamicCalibrationModel(
    System.Windows.DependencyObject, System.IDisposable, IDynamicCalibrationSetupModel
):  # Class
    def __init__(self) -> None: ...

    CalibrationRangesProperty: System.Windows.DependencyProperty  # static
    CurrentCalibrationRangeProperty: System.Windows.DependencyProperty  # static
    CurrentCompoundProperty: System.Windows.DependencyProperty  # static
    CurrentIonGroupProperty: System.Windows.DependencyProperty  # static
    IonGroupsProperty: System.Windows.DependencyProperty  # static

    AppCommandContext: IAppCommandContext  # readonly
    CalibrationRangeViewModel: ICalibrationRangeViewModel  # readonly
    CalibrationRanges: List[ICalibrationRangeItem]
    CalibrationViewModel: ICalibrationViewModel  # readonly
    CompoundsViewModel: ICompoundsViewModel  # readonly
    CurrentCalibrationRange: ICalibrationRangeItem
    CurrentCompound: System.Data.DataRowView
    CurrentIonGroup: IIonGroupItem
    IonGroupGraphicsViewModel: IIonGroupGraphicsViewModel  # readonly
    IonGroupViewModel: IIonGroupViewModel  # readonly
    IonGroups: List[IIonGroupItem]
    QualifiersViewModel: IQualifiersViewModel  # readonly
    Window: System.Windows.Window

    def Dispose(self) -> None: ...

class IonGroupGraphicsViewModel(
    IIonGroupGraphicsViewModel, System.Windows.DependencyObject, System.IDisposable
):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...

    PlotSeriesProperty: System.Windows.DependencyProperty  # static
    SelectedSeriesProperty: System.Windows.DependencyProperty  # static

    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly
    PlotSeries: List[IIonGroupPlotSeries]
    SelectedSeries: IIonGroupPlotSeries

    def Dispose(self) -> None: ...

class IonGroupItem(IIonGroupItem):  # Class
    def __init__(
        self,
        id: int,
        ionGroup: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.ICrossSampleIonGroup,
    ) -> None: ...

    ConcentrationRangeString: str  # readonly
    CrossSampleIonGroup: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DynamicQuant.ICrossSampleIonGroup
    )  # readonly
    IonGroupID: int  # readonly
    MZ: float  # readonly
    TargetCompoundID: int  # readonly
    UnsaturatedRangeString: str  # readonly

class IonGroupViewModel(System.IDisposable, IIonGroupViewModel):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...

    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly

    def Dispose(self) -> None: ...

class QualifiersViewModel(
    IQualifiersViewModel, System.Windows.DependencyObject, System.IDisposable
):  # Class
    def __init__(self, model: IDynamicCalibrationSetupModel) -> None: ...

    DynamicCalibrationSetupModel: IDynamicCalibrationSetupModel  # readonly
    TargetQualifier: System.Data.DataView  # readonly

    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Common

class BatchTable(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.BatchTable]
):  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int  # static # readonly
    FileName: str = ...  # static # readonly

    DefaultBatchSingleMode: bool
    DefaultBatchTableViewMode: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode
    )
    SchemaVersion: int
    VisibleColumns: List[Agilent.MassHunter.Quantitative.Startup.Common.VisibleColumns]

    def SaveTo(self, stream: System.IO.Stream) -> None: ...
    def Equals(
        self, bt: Agilent.MassHunter.Quantitative.Startup.Common.BatchTable
    ) -> bool: ...
    @staticmethod
    def Load(
        filepath: str,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.BatchTable: ...
    @staticmethod
    def CreateDefault() -> (
        Agilent.MassHunter.Quantitative.Startup.Common.BatchTable
    ): ...
    def SetupBatchTable(self) -> None: ...

class ColumnLabel(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabel]
):  # Class
    def __init__(self) -> None: ...

    Hidden: bool
    Labels: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText]
    Name: str
    Relation: str

    def FindLocalizableText(
        self, culture: System.Globalization.CultureInfo
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText: ...
    def Equals(
        self, label: Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabel
    ) -> bool: ...

class ColumnLabels(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabels]
):  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int  # static # readonly
    FileName_QuantDefault: str = ...  # static # readonly

    Labels: List[Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabel]
    SchemaVersion: int

    def SaveTo(self, stream: System.IO.Stream) -> None: ...
    def Equals(
        self, labels: Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabels
    ) -> bool: ...
    @overload
    @staticmethod
    def Load(
        filepath: str,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabels: ...
    @overload
    @staticmethod
    def Load(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        filepath: str,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabels: ...
    def SetupQuantColumnLabels(
        self,
        instrumentType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
    ) -> None: ...
    @staticmethod
    def CreateDefault() -> (
        Agilent.MassHunter.Quantitative.Startup.Common.ColumnLabels
    ): ...

class Deploy:  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVeresion: int  # static # readonly
    FileExt: str = ...  # static # readonly

    Configurations: List[
        Agilent.MassHunter.Quantitative.Startup.Common.DeployConfiguration
    ]
    Embedded: bool
    SchemaVersion: int

    @staticmethod
    def GenerateDeployment(
        pathName: str,
        startupRootFolder: str,
        configurationsToArchilve: List[str],
        embed: bool,
    ) -> None: ...
    @staticmethod
    def ExtractDeployment(
        pathName: str,
        destinationFolder: str,
        configurationCallback: System.Action[
            Agilent.MassHunter.Quantitative.Startup.Common.DeployConfiguration
        ],
    ) -> None: ...

class DeployConfiguration:  # Class
    def __init__(self) -> None: ...

    Name: str
    PathName: str

class LocalizableText(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText]
):  # Class
    def __init__(self) -> None: ...

    Culture: str
    Value: str
    _Culture: System.Globalization.CultureInfo  # readonly

    @staticmethod
    def FindLocalizableText(
        texts: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText],
        culture: System.Globalization.CultureInfo,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText: ...
    @staticmethod
    def MatchCulture(
        ci: System.Globalization.CultureInfo, textci: System.Globalization.CultureInfo
    ) -> bool: ...
    @overload
    @staticmethod
    def Equals(
        lt: Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText,
    ) -> bool: ...
    @overload
    @staticmethod
    def Equals(
        arr1: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText],
        arr2: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText],
    ) -> bool: ...

class OutlierSetting(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.OutlierSetting]
):  # Class
    def __init__(self) -> None: ...

    Hidden: bool
    Labels: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText]
    OutlierColumn: Agilent.MassSpectrometry.DataAnalysis.Quantitative.OutlierColumns

    def Equals(
        self, o: Agilent.MassHunter.Quantitative.Startup.Common.OutlierSetting
    ) -> bool: ...

class Outliers(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.Outliers]
):  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int  # static # readonly
    FileName: str = ...  # static # readonly

    OutlierSettings: List[Agilent.MassHunter.Quantitative.Startup.Common.OutlierSetting]
    SchemaVersion: int

    def SaveTo(self, stream: System.IO.Stream) -> None: ...
    def Equals(
        self, o: Agilent.MassHunter.Quantitative.Startup.Common.Outliers
    ) -> bool: ...
    @staticmethod
    def Load(
        filepath: str,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.Outliers: ...
    @staticmethod
    def CreateDefault() -> Agilent.MassHunter.Quantitative.Startup.Common.Outliers: ...
    def SetupConfiguration(self) -> None: ...

class SampleTypeLabel(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.SampleTypeLabel]
):  # Class
    def __init__(self) -> None: ...

    Labels: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText]
    SampleType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleType
    Visible: bool

    def FindLabel(
        self, culture: System.Globalization.CultureInfo
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText: ...
    def Equals(
        self, st: Agilent.MassHunter.Quantitative.Startup.Common.SampleTypeLabel
    ) -> bool: ...

class SampleTypes(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.SampleTypes]
):  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int  # static # readonly
    FileName_QuantDefault: str = ...  # static # readonly

    SampleTypeLabels: List[
        Agilent.MassHunter.Quantitative.Startup.Common.SampleTypeLabel
    ]
    SchemaVersion: int

    def SaveTo(self, stream: System.IO.Stream) -> None: ...
    def Equals(
        self, sts: Agilent.MassHunter.Quantitative.Startup.Common.SampleTypes
    ) -> bool: ...
    @staticmethod
    def Load(
        filepath: str,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.SampleTypes: ...
    @staticmethod
    def CreateDefault() -> (
        Agilent.MassHunter.Quantitative.Startup.Common.SampleTypes
    ): ...
    def SetupConfiguration(self, culture: System.Globalization.CultureInfo) -> None: ...

class Startup(
    System.IEquatable[Agilent.MassHunter.Quantitative.Startup.Common.Startup]
):  # Class
    def __init__(self) -> None: ...

    CurrentSchemaVersion: int  # static # readonly
    FileName: str = ...  # static # readonly
    FileName_WpfCagToolsDefault: str = ...  # static # readonly
    FileName_WpfCiwToolsDefault: str = ...  # static # readonly
    FileName_WpfToolsDefault: str = ...  # static # readonly

    AllowFlexibleDocking: bool
    DisplayNames: List[Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText]
    Instrument: str
    SchemaVersion: int
    StartupLocation: str  # readonly
    _Instrument: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    )  # readonly

    def SaveTo(self, stream: System.IO.Stream) -> None: ...
    def Equals(
        self, startup: Agilent.MassHunter.Quantitative.Startup.Common.Startup
    ) -> bool: ...
    @staticmethod
    def Load(
        startupLocation: str,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.Startup: ...
    @staticmethod
    def CreateDefault(
        folderName: str,
        instrument: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.Startup: ...
    def GetDisplayName(
        self, culture: System.Globalization.CultureInfo
    ) -> Agilent.MassHunter.Quantitative.Startup.Common.LocalizableText: ...

class StartupException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...
    @overload
    def __init__(
        self,
        info: System.Runtime.Serialization.SerializationInfo,
        context: System.Runtime.Serialization.StreamingContext,
    ) -> None: ...

class VisibleColumns:  # Class
    def __init__(self) -> None: ...

    Columns: List[str]
    Relation: str
    SingleMode: bool
    TableViewMode: Agilent.MassSpectrometry.DataAnalysis.Quantitative.TableViewMode

    def GetHashCode(self) -> int: ...
    @staticmethod
    def ArrayEquals(
        arr1: List[Agilent.MassHunter.Quantitative.Startup.Common.VisibleColumns],
        arr2: List[Agilent.MassHunter.Quantitative.Startup.Common.VisibleColumns],
    ) -> bool: ...
    @staticmethod
    def StringArrayEquals(arr1: List[str], arr2: List[str]) -> bool: ...
    def Equals(self, obj: Any) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel

class IBatchTableViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def Save(self) -> None: ...

class IColumnLabelsViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def Save(self) -> None: ...

class IControlPanelViewModel(object):  # Interface
    BatchTableViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IBatchTableViewModel
    )  # readonly
    ColumnLabelsViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IColumnLabelsViewModel
    )  # readonly
    Configurations: List[str]  # readonly
    CustomizeRibbonViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ICustomizeRibbonViewModel
    )  # readonly
    DefaultConfiguration: str
    GeneralSettingsViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IGeneralSettingsViewModel
    )  # readonly
    ManageViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IManageViewModel
    )  # readonly
    OutliersViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IOutliersViewModel
    )  # readonly
    SampleTypesViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ISampleTypesViewModel
    )  # readonly
    SelectedConfiguration: str
    StartupRootFolder: str
    Window: System.Windows.Window  # readonly

    def UpdateConfigurations(self) -> None: ...
    def EditSelectedConfiguration(self) -> None: ...

class ICustomizeRibbonViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def Save(self) -> None: ...

class IGeneralSettingsViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    InstrumentType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType
    )  # readonly

    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def Save(self) -> None: ...

class IManageViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    RootModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IControlPanelViewModel
    )  # readonly

    def DeleteSelectedConfiguration(self) -> None: ...
    def CreateNewConfiguration(
        self,
        parent: System.Windows.Window,
        folderName: str,
        instrument: Agilent.MassSpectrometry.DataAnalysis.Quantitative.InstrumentType,
    ) -> bool: ...
    def Deploy(self) -> None: ...
    def CopyConfiguration(
        self, parent: System.Windows.Window, copyFrom: str, copyTo: str
    ) -> bool: ...
    def BrowseStartupRootFolder(self) -> None: ...

class IOutliersViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def Save(self) -> None: ...

class ISampleTypesViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
):  # Interface
    def ResetToDefault(self) -> None: ...
    def Reload(self) -> None: ...
    def Save(self) -> None: ...

class ITask(object):  # Interface
    Content: System.Windows.UIElement  # readonly
    IsEnabled: bool  # readonly
    Title: str  # readonly

    def Leaving(self) -> bool: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...
    def Activate(self) -> None: ...

class ITaskGroup(object):  # Interface
    IsEnabled: bool  # readonly
    Tasks: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask
    ]  # readonly
    Title: str  # readonly

class TaskViewModelBase(System.Windows.DependencyObject):  # Class
    RootModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IControlPanelViewModel
    )  # readonly

    def Leaving(self) -> bool: ...
    def IsDirty(self) -> bool: ...
    def Save(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ChromRegion, Component, ComponentPerceptionParams, IDataAccess
from .FD import Feature, FeatureDetector, IFeatureSet

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.FeatureDeconvolution

class TofFeatureDeconvolution:  # Class
    def __init__(self) -> None: ...
    def RunMultiParameterDeconvolution(
        self,
        preSelectedFeatures: System.Collections.Generic.List[Feature],
        dataAccess: IDataAccess,
        cpParamsList: System.Collections.Generic.List[ComponentPerceptionParams],
    ) -> List[System.Collections.Generic.List[Component]]: ...
    @overload
    def Run(
        self,
        featureSet: IFeatureSet,
        dataAccess: IDataAccess,
        featureDetector: FeatureDetector,
        cpParams: ComponentPerceptionParams,
    ) -> System.Collections.Generic.List[Component]: ...
    @overload
    def Run(
        self,
        preSelectedFeatures: System.Collections.Generic.List[Feature],
        dataAccess: IDataAccess,
        cpParams: ComponentPerceptionParams,
    ) -> System.Collections.Generic.List[Component]: ...
    @overload
    def Run(
        self, chromRegion: ChromRegion, cpParams: ComponentPerceptionParams
    ) -> System.Collections.Generic.List[Component]: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: System.Windows.Interactivity

class AttachableCollection(
    System.Windows.FreezableCollection[T],
    Generic[T],
    Iterable[T],
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Collections.Specialized.INotifyCollectionChanged,
    Iterable[Any],
    System.ComponentModel.INotifyPropertyChanged,
    List[Any],
    System.Windows.Interactivity.IAttachedObject,
    List[T],
    Sequence[T],
    Sequence[Any],
):  # Class
    def Attach(self, dependencyObject: System.Windows.DependencyObject) -> None: ...
    def Detach(self) -> None: ...

class Behavior(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Animation.Animatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    def Attach(self, dependencyObject: System.Windows.DependencyObject) -> None: ...
    def Detach(self) -> None: ...

class BehaviorCollection(
    Iterable[System.Windows.Interactivity.Behavior],
    System.Windows.ISealable,
    System.Windows.Interactivity.AttachableCollection[
        System.Windows.Interactivity.Behavior
    ],
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    Iterable[Any],
    List[System.Windows.Interactivity.Behavior],
    List[Any],
    Sequence[System.Windows.Interactivity.Behavior],
    System.Collections.Specialized.INotifyCollectionChanged,
    System.ComponentModel.INotifyPropertyChanged,
    System.Windows.Interactivity.IAttachedObject,
    Sequence[Any],
):  # Class
    ...

class Behavior(
    System.Windows.ISealable,
    Generic[T],
    System.Windows.Interactivity.Behavior,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    ...

class CustomPropertyValueEditor(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Element: System.Windows.Interactivity.CustomPropertyValueEditor = (
        ...
    )  # static # readonly
    ElementBinding: System.Windows.Interactivity.CustomPropertyValueEditor = (
        ...
    )  # static # readonly
    PropertyBinding: System.Windows.Interactivity.CustomPropertyValueEditor = (
        ...
    )  # static # readonly
    StateName: System.Windows.Interactivity.CustomPropertyValueEditor = (
        ...
    )  # static # readonly
    Storyboard: System.Windows.Interactivity.CustomPropertyValueEditor = (
        ...
    )  # static # readonly

class CustomPropertyValueEditorAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(
        self,
        customPropertyValueEditor: System.Windows.Interactivity.CustomPropertyValueEditor,
    ) -> None: ...

    CustomPropertyValueEditor: (
        System.Windows.Interactivity.CustomPropertyValueEditor
    )  # readonly

class DefaultTriggerAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    @overload
    def __init__(
        self, targetType: System.Type, triggerType: System.Type, parameter: Any
    ) -> None: ...
    @overload
    def __init__(
        self, targetType: System.Type, triggerType: System.Type, parameters: List[Any]
    ) -> None: ...

    Parameters: Iterable[Any]  # readonly
    TargetType: System.Type  # readonly
    TriggerType: System.Type  # readonly

    def Instantiate(self) -> System.Windows.Interactivity.TriggerBase: ...

class DependencyObjectHelper:  # Class
    @staticmethod
    def GetSelfAndAncestors(
        dependencyObject: System.Windows.DependencyObject,
    ) -> Iterable[System.Windows.DependencyObject]: ...

class EventObserver(System.IDisposable):  # Class
    def __init__(
        self,
        eventInfo: System.Reflection.EventInfo,
        target: Any,
        handler: System.Delegate,
    ) -> None: ...
    def Dispose(self) -> None: ...

class EventTrigger(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.EventTriggerBase,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, eventName: str) -> None: ...

    EventNameProperty: System.Windows.DependencyProperty  # static # readonly

    EventName: str

class EventTriggerBase(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Interactivity.TriggerBase,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    SourceNameProperty: System.Windows.DependencyProperty  # static # readonly
    SourceObjectProperty: System.Windows.DependencyProperty  # static # readonly

    Source: Any  # readonly
    SourceName: str
    SourceObject: Any

class EventTriggerBase(
    System.Windows.ISealable,
    Generic[T],
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.EventTriggerBase,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    Source: T  # readonly

class IAttachedObject(object):  # Interface
    AssociatedObject: System.Windows.DependencyObject  # readonly

    def Attach(self, dependencyObject: System.Windows.DependencyObject) -> None: ...
    def Detach(self) -> None: ...

class Interaction:  # Class
    @staticmethod
    def GetBehaviors(
        obj: System.Windows.DependencyObject,
    ) -> System.Windows.Interactivity.BehaviorCollection: ...
    @staticmethod
    def GetTriggers(
        obj: System.Windows.DependencyObject,
    ) -> System.Windows.Interactivity.TriggerCollection: ...

class InvokeCommandAction(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.TriggerAction[System.Windows.DependencyObject],
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    def __init__(self) -> None: ...

    CommandParameterProperty: System.Windows.DependencyProperty  # static # readonly
    CommandProperty: System.Windows.DependencyProperty  # static # readonly

    Command: System.Windows.Input.ICommand
    CommandName: str
    CommandParameter: Any

class PreviewInvokeEventArgs(System.EventArgs):  # Class
    def __init__(self) -> None: ...

    Cancelling: bool

class TargetedTriggerAction(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Interactivity.TriggerAction,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    TargetNameProperty: System.Windows.DependencyProperty  # static # readonly
    TargetObjectProperty: System.Windows.DependencyProperty  # static # readonly

    TargetName: str
    TargetObject: Any

class TargetedTriggerAction(
    System.Windows.ISealable,
    Generic[T],
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Interactivity.TargetedTriggerAction,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    ...

class TriggerAction(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Animation.Animatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    IsEnabledProperty: System.Windows.DependencyProperty  # static # readonly

    IsEnabled: bool

    def Attach(self, dependencyObject: System.Windows.DependencyObject) -> None: ...
    def Detach(self) -> None: ...

class TriggerActionCollection(
    Sequence[System.Windows.Interactivity.TriggerAction],
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    List[System.Windows.Interactivity.TriggerAction],
    Iterable[Any],
    Iterable[System.Windows.Interactivity.TriggerAction],
    List[Any],
    System.Windows.Interactivity.AttachableCollection[
        System.Windows.Interactivity.TriggerAction
    ],
    System.Collections.Specialized.INotifyCollectionChanged,
    System.ComponentModel.INotifyPropertyChanged,
    System.Windows.Interactivity.IAttachedObject,
    Sequence[Any],
):  # Class
    ...

class TriggerAction(
    System.Windows.ISealable,
    Generic[T],
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Interactivity.TriggerAction,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    ...

class TriggerBase(
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Animation.Animatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    ActionsProperty: System.Windows.DependencyProperty  # static # readonly

    Actions: System.Windows.Interactivity.TriggerActionCollection  # readonly

    def Attach(self, dependencyObject: System.Windows.DependencyObject) -> None: ...
    def Detach(self) -> None: ...

    PreviewInvoke: System.EventHandler[
        System.Windows.Interactivity.PreviewInvokeEventArgs
    ]  # Event

class TriggerBase(
    System.Windows.ISealable,
    Generic[T],
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Interactivity.TriggerBase,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Interactivity.IAttachedObject,
):  # Class
    ...

class TriggerCollection(
    Iterable[System.Windows.Interactivity.TriggerBase],
    Sequence[System.Windows.Interactivity.TriggerBase],
    System.Windows.ISealable,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Collections.Specialized.INotifyCollectionChanged,
    System.Windows.Interactivity.AttachableCollection[
        System.Windows.Interactivity.TriggerBase
    ],
    Iterable[Any],
    List[Any],
    System.ComponentModel.INotifyPropertyChanged,
    System.Windows.Interactivity.IAttachedObject,
    List[System.Windows.Interactivity.TriggerBase],
    Sequence[Any],
):  # Class
    ...

class TypeConstraintAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, constraint: System.Type) -> None: ...

    Constraint: System.Type  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import IFunction, Molecule
from .BasicTypes import PeakList

# Stubs for namespace: IsotopePatternCalculator

class CalculatorBase:  # Class
    ...

class IIsotopePattern(object):  # Interface
    DeltaMZ: float  # readonly
    MZAtMax: float  # readonly
    MZCentroid: float  # readonly
    MZMono: float  # readonly
    MZStandardDeviationSquared: float  # readonly
    Peaks: PeakList  # readonly
    SignalEnd: int  # readonly
    Spectrum: List[float]  # readonly
    StartMZ: float  # readonly

class IsotopePatternCalculatorAlgebra(
    IsotopePatternCalculator.CalculatorBase, IsotopePatternCalculator.IIsotopePattern
):  # Class
    @overload
    def __init__(
        self,
        molecule: Molecule,
        z: int,
        userParameter: IsotopePatternCalculator.IsotopePatternCalculatorParameters,
    ) -> None: ...
    @overload
    def __init__(
        self,
        elementCounts: Dict[int, float],
        maxPeakCount: int,
        m0: float,
        userParameter: IsotopePatternCalculator.IsotopePatternCalculatorParameters,
    ) -> None: ...

    DeltaMZ: float  # readonly
    MZAtMax: float  # readonly
    MZCentroid: float  # readonly
    MZMono: float  # readonly
    MZStandardDeviationSquared: float  # readonly
    Peaks: PeakList  # readonly
    SignalEnd: int  # readonly
    Spectrum: List[float]  # readonly
    StartMZ: float  # readonly

class IsotopePatternCalculatorFFT(
    IsotopePatternCalculator.CalculatorBase, IsotopePatternCalculator.IIsotopePattern
):  # Class
    def __init__(
        self,
        neutralMolecule: Molecule,
        z: int,
        userParameter: IsotopePatternCalculator.IsotopePatternCalculatorParameters,
    ) -> None: ...

    DeltaMZ: float  # readonly
    MZAtMax: float  # readonly
    MZCentroid: float  # readonly
    MZMono: float  # readonly
    MZStandardDeviationSquared: float  # readonly
    Peaks: PeakList  # readonly
    SignalEnd: int  # readonly
    Spectrum: List[float]  # readonly
    StartMZ: float  # readonly

class IsotopePatternCalculatorParameters:  # Class
    def __init__(self) -> None: ...

    MinSamplingRate: float
    PeakWidthFunction: IFunction
    ResolveFineStructure: bool

    def InitializeForTOF(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .DataSource import IDataSource
from .Template import (
    BreakLocation,
    IDataBinding,
    IGraphics,
    IImage,
    IPage,
    IPrintGraphicsSettings,
    IReportItem,
    IReportTemplate,
    IScriptable,
    ITable,
    ITableCell,
    ITextbox,
    PageSize,
)

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Engine

class IGraphicsCanvas(object):  # Interface
    IgnoreFontName: bool

    def ConvertBounds(
        self, bounds: System.Drawing.RectangleF
    ) -> System.Drawing.RectangleF: ...
    def DrawImage(
        self,
        image: System.Drawing.Image,
        x: float,
        y: float,
        width: float,
        height: float,
    ) -> None: ...
    def GetGraphics(self) -> T: ...

class IRenderingEvents(object):  # Interface
    def Render(
        self,
        evt: Agilent.MassHunter.ReportBuilder.Engine.RenderingEvent,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        item: IReportItem,
        renderingObject: Any,
    ) -> bool: ...

class IReportContext(object):  # Interface
    ComplianceDisplayName: str
    ComplianceName: str
    ComplianceServer: str
    CurrentBoundObject: Any  # readonly
    CurrentVersion: str  # readonly
    DataSource: IDataSource  # readonly
    PageSize: PageSize
    PreviewAborted: bool
    PreviewMaxNumPages: int
    PrintGraphicsSettings: IPrintGraphicsSettings  # readonly
    Renderer: Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer  # readonly
    ScriptEngine: Agilent.MassHunter.ReportBuilder.Engine.IScriptEngine  # readonly
    StartDateTime: System.DateTime  # readonly
    Template: IReportTemplate  # readonly
    TemplateFilePath: str  # readonly
    UserName: str

    def PopBoundObject(self, dataBindingName: str) -> None: ...
    @overload
    def LocalizeText(self, key: str) -> str: ...
    @overload
    def LocalizeText(
        self, culture: System.Globalization.CultureInfo, key: str, value_: str
    ) -> bool: ...
    def HasCustomMacro(self, key: str) -> bool: ...
    def PopDataBinding(self, dataBinding: IDataBinding) -> None: ...
    def ProcessCustomMacros(self, value_: str) -> str: ...
    def PushBoundObject(self, dataBindingName: str, value_: Any) -> None: ...
    def FindDataBinding(self, name: str) -> IDataBinding: ...
    def PushDataBinding(self, dataBinding: IDataBinding) -> None: ...
    def CheckAbort(self) -> None: ...
    def GetCustomMacro(self, key: str) -> str: ...
    def GetBoundObject(self, dataBindingName: str) -> Any: ...
    def SetCustomMacro(self, key: str, value_: str) -> None: ...

class IReportRenderer(System.IDisposable):  # Interface
    Context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext

    def RenderImage(self, image: IImage) -> None: ...
    def StartDocument(self) -> None: ...
    def PageBreak(self) -> None: ...
    def RenderTable(
        self, numColumns: int
    ) -> Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer: ...
    def RenderGraphics(self, graphics: IGraphics) -> None: ...
    def RenderText(self, textbox: ITextbox) -> None: ...
    def EndDocument(self) -> None: ...
    def SetPage(self, page: IPage) -> None: ...

class IReportScriptContext(object):  # Interface
    ComplianceDisplayName: str  # readonly
    ComplianceName: str  # readonly
    ComplianceServer: str  # readonly
    CurrentPage: int  # readonly
    CurrentVersion: str  # readonly
    DataSource: IDataSource  # readonly
    StartDateTime: System.DateTime  # readonly
    TemplateFilePath: str  # readonly
    TotalPages: int  # readonly
    UserName: str  # readonly

    def LocalizeText(self, text: str) -> str: ...

class IScriptEngine(object):  # Interface
    def RemoveVariable(self, name: str) -> None: ...
    def PushTemplateItem(self, id: str, item: IScriptable) -> None: ...
    def SetVariable(self, name: str, value_: Any) -> None: ...
    def PopTemplateItem(self, id: str, item: IScriptable) -> None: ...
    def Eval(self, expression: str) -> Any: ...

class ITableRenderer(object):  # Interface
    def SetColumnWidths(self, widths: List[float]) -> None: ...
    def EndTable(self) -> None: ...
    def SetProperties(self, table: ITable) -> None: ...
    def StartHeader(self) -> None: ...
    def EndHeader(self) -> None: ...
    def AddCell(self, cell: ITableCell) -> None: ...
    def EndRow(self) -> None: ...

class Macros:  # Class
    def __init__(self) -> None: ...

    CurrentVersion: str = ...  # static # readonly
    GeneratedDATE: str = ...  # static # readonly
    GeneratedDate: str = ...  # static # readonly
    GeneratedDateTime: str = ...  # static # readonly
    GeneratedTime: str = ...  # static # readonly
    Page: str = ...  # static # readonly
    Pages: str = ...  # static # readonly

class ProcessReport:  # Class
    def __init__(
        self,
        template: IReportTemplate,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
    ) -> None: ...

    ReportContext: Agilent.MassHunter.ReportBuilder.Engine.IReportContext  # readonly
    ReportTemplate: IReportTemplate  # readonly

    def ProcessPage(self, page: IPage) -> None: ...
    @staticmethod
    def ProcessBinding(
        parentBinding: IDataBinding,
        dataBinding: IDataBinding,
        pageBreak: BreakLocation,
        context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext,
        renderer: Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer,
        action: System.Action,
    ) -> None: ...
    def Process(self) -> None: ...

class ProcessTable:  # Class
    @staticmethod
    def Process(
        table: ITable,
        renderer: Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer,
        tableRenderer: Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer,
    ) -> None: ...

class RenderingEvent(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    TableCell: Agilent.MassHunter.ReportBuilder.Engine.RenderingEvent = (
        ...
    )  # static # readonly
    TextBox: Agilent.MassHunter.ReportBuilder.Engine.RenderingEvent = (
        ...
    )  # static # readonly

class ReportContext(Agilent.MassHunter.ReportBuilder.Engine.IReportContext):  # Class
    def __init__(
        self,
        templateFilePath: str,
        template: IReportTemplate,
        dataSource: IDataSource,
        renderer: Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer,
        startDateTime: System.DateTime,
        abort: System.Threading.WaitHandle,
    ) -> None: ...

    ComplianceDisplayName: str
    ComplianceName: str
    ComplianceServer: str
    CurrentBoundObject: Any  # readonly
    CurrentVersion: str  # readonly
    DataSource: IDataSource  # readonly
    PageSize: PageSize
    PreviewAborted: bool
    PreviewMaxNumPages: int
    PrintGraphicsSettings: IPrintGraphicsSettings  # readonly
    Renderer: Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer  # readonly
    ScriptEngine: Agilent.MassHunter.ReportBuilder.Engine.IScriptEngine  # readonly
    StartDateTime: System.DateTime  # readonly
    Template: IReportTemplate  # readonly
    TemplateFilePath: str  # readonly
    UserName: str

    def PopBoundObject(self, dataBindingName: str) -> None: ...
    @overload
    def LocalizeText(self, name: str) -> str: ...
    @overload
    def LocalizeText(
        self, culture: System.Globalization.CultureInfo, name: str, value_: str
    ) -> bool: ...
    @staticmethod
    def GetCurrentVersion() -> str: ...
    def HasCustomMacro(self, key: str) -> bool: ...
    def PopDataBinding(self, dataBinding: IDataBinding) -> None: ...
    def ProcessCustomMacros(self, value_: str) -> str: ...
    def PushBoundObject(self, dataBindingName: str, value_: Any) -> None: ...
    def FindDataBinding(self, name: str) -> IDataBinding: ...
    def PushDataBinding(self, dataBinding: IDataBinding) -> None: ...
    def CheckAbort(self) -> None: ...
    def GetCustomMacro(self, key: str) -> str: ...
    def GetBoundObject(self, dataBindingName: str) -> Any: ...
    def SetCustomMacro(self, key: str, value_: str) -> None: ...

class ReportScriptContext(
    Agilent.MassHunter.ReportBuilder.Engine.IReportScriptContext
):  # Class
    ComplianceDisplayName: str  # readonly
    ComplianceName: str  # readonly
    ComplianceServer: str  # readonly
    CurrentPage: int  # readonly
    CurrentVersion: str  # readonly
    DataSource: IDataSource  # readonly
    StartDateTime: System.DateTime  # readonly
    TemplateFilePath: str  # readonly
    TotalPages: int  # readonly
    UserName: str  # readonly

    def LocalizeText(self, text: str) -> str: ...

class ScriptEngine(Agilent.MassHunter.ReportBuilder.Engine.IScriptEngine):  # Class
    def __init__(self) -> None: ...
    def RemoveVariable(self, name: str) -> None: ...
    def PushTemplateItem(self, id: str, item: IScriptable) -> None: ...
    def SetVariable(self, name: str, value_: Any) -> None: ...
    def PopTemplateItem(self, id: str, item: IScriptable) -> None: ...
    def Eval(self, expression: str) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from .ToolManager import IToolManager
from .ToolState import IToolState, PaneToolbar

# Stubs for namespace: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions

class ApplicationCommand(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...

    Command: str

    def Build(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, toolManager: IToolManager
    ) -> None: ...

class ApplicationMenu2010(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...

    Items: List[
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010Item
    ]

    def GetHashCode(self) -> int: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010: ...
    def Build(
        self,
        menu2010: Infragistics.Windows.Ribbon.ApplicationMenu2010,
        toolManager: IToolManager,
    ) -> Infragistics.Windows.Ribbon.ApplicationMenu2010: ...
    def Equals(self, obj: Any) -> bool: ...

class ApplicationMenu2010Item(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Menu
):  # Class
    def __init__(self) -> None: ...

    CloseAppMenu: bool
    InitialSelected: bool
    IsTab: bool

    def ShallowCopy(
        self,
    ) -> (
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010Item
    ): ...
    def Build(self, toolMgr: IToolManager) -> Any: ...

class ApplicationMenu2010ItemSeparator(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010Item
):  # Class
    def __init__(self) -> None: ...
    def ShallowCopy(
        self,
    ) -> (
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010ItemSeparator
    ): ...
    def Build(self, toolManager: IToolManager) -> Any: ...

class ApplicationMenu2010TabCommand(System.Windows.Input.ICommand):  # Class
    def __init__(self, toolManager: IToolManager, toolState: IToolState) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class Button(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase):  # Class
    def __init__(self) -> None: ...
    def Equals(self, obj: Any) -> bool: ...
    def Build(
        self, toolManager: IToolManager, imageColor: System.Windows.Media.Color
    ) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Button: ...
    def BuildContextMenuItem(self, toolManager: IToolManager) -> Any: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class CheckButton(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Button
):  # Class
    def __init__(self) -> None: ...

    HasGlyph: bool

    def Equals(self, obj: Any) -> bool: ...
    def Build(
        self, toolManager: IToolManager, imageColor: System.Windows.Media.Color
    ) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.CheckButton: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class ComboBox(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...

    Width: int

    def Equals(self, obj: Any) -> bool: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ComboBox: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class Command(System.Windows.Input.ICommand, System.IDisposable):  # Class
    def __init__(self, toolManager: IToolManager) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Dispose(self) -> None: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class ContextMenu(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Menu):  # Class
    def __init__(self) -> None: ...

    Pane: str

    def GetHashCode(self) -> int: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ContextMenu: ...
    def BuildContextMenu(
        self, toolManager: IToolManager
    ) -> System.Windows.Controls.ContextMenu: ...
    def Equals(self, obj: Any) -> bool: ...

class ContextualTabGroup:  # Class
    def __init__(self) -> None: ...

    ID: str
    TabItems: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.TabItem]

    def GetHashCode(self) -> int: ...
    def Build(
        self, toolManager: IToolManager
    ) -> Infragistics.Windows.Ribbon.ContextualTabGroup: ...
    def Equals(self, obj: Any) -> bool: ...

class ExplorerBar(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...

    Groups: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Group]

    def GetHashCode(self) -> int: ...
    def Build(
        self,
        toolManager: IToolManager,
        parent: System.Windows.Controls.Panel,
        imageResources: System.Resources.ResourceManager,
    ) -> None: ...
    def Equals(self, obj: Any) -> bool: ...

class Gallery(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase):  # Class
    def __init__(self) -> None: ...

    Groups: List[
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.GalleryItemGroup
    ]
    Items: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.GalleryItem]
    MaxPreviewColumns: int
    MinPreviewColumns: int
    ToolItemBehavior: Infragistics.Windows.Ribbon.GalleryToolItemBehavior

    def Build(self, toolManager: IToolManager) -> Any: ...

class GalleryItem(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...
    def _Build(
        self, toolManager: IToolManager
    ) -> Infragistics.Windows.Ribbon.GalleryItem: ...

class GalleryItemGroup:  # Class
    def __init__(self) -> None: ...

    ID: str
    ItemKeys: List[str]

    def Build(
        self, toolManager: IToolManager
    ) -> Infragistics.Windows.Ribbon.GalleryItemGroup: ...

class Group(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase):  # Class
    def __init__(self) -> None: ...

    Expanded: bool
    Tools: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase]

    def Equals(self, obj: Any) -> bool: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Group: ...
    def GetHashCode(self) -> int: ...
    def BuildGroup(
        self, toolManager: IToolManager
    ) -> Infragistics.Windows.Ribbon.RibbonGroup: ...
    def BuildTasks(self, toolManager: IToolManager) -> System.Windows.UIElement: ...

class Label(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase):  # Class
    def __init__(self) -> None: ...
    def Equals(self, obj: Any) -> bool: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Label: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class Menu(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Button):  # Class
    def __init__(self) -> None: ...

    ButtonType: str
    ShouldDisplayGalleryPreview: bool
    Tools: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase]

    def Equals(self, obj: Any) -> bool: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Menu: ...
    def BuildContextMenuItem(self, toolManager: IToolManager) -> Any: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class MethodTasks:  # Class
    def __init__(self) -> None: ...

    Groups: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Group]

    def BuildTasks(
        self, panel: System.Windows.Controls.Panel, toolManager: IToolManager
    ) -> None: ...
    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class PopupMenu(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Menu):  # Class
    def __init__(self) -> None: ...
    def GetHashCode(self) -> int: ...
    def BuildContextMenuItem(self, toolManager: IToolManager) -> Any: ...
    def Equals(self, obj: Any) -> bool: ...

class QuickAccessToolbar:  # Class
    def __init__(self) -> None: ...

    Items: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase]

    def GetHashCode(self) -> int: ...
    def Build(
        self, toolManager: IToolManager, ribbon: Infragistics.Windows.Ribbon.XamRibbon
    ) -> Infragistics.Windows.Ribbon.QuickAccessToolbar: ...
    def Equals(self, obj: Any) -> bool: ...

class RadioButton(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.CheckButton
):  # Class
    def __init__(self) -> None: ...
    def GetHashCode(self) -> int: ...
    def BuildContextMenuItem(self, toolManager: IToolManager) -> Any: ...
    def Equals(self, obj: Any) -> bool: ...

class Ribbon:  # Class
    def __init__(self) -> None: ...

    ApplicationMenu2010: (
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010
    )
    ContextualTabGroups: List[
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ContextualTabGroup
    ]
    IsMinimized: bool
    QuickAccessToolbar: (
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.QuickAccessToolbar
    )
    TabItems: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.TabItem]

    def GetHashCode(self) -> int: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Ribbon: ...
    def Build(
        self, ribbon: Infragistics.Windows.Ribbon.XamRibbon, toolManager: IToolManager
    ) -> None: ...
    def Equals(self, obj: Any) -> bool: ...

class Separator(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...
    def Equals(self, obj: Any) -> bool: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Separator: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class TabItem(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase):  # Class
    def __init__(self) -> None: ...

    Groups: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Group]

    def GetHashCode(self) -> int: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.TabItem: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def Equals(self, obj: Any) -> bool: ...

class TextBox(Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase):  # Class
    def __init__(self) -> None: ...

    IsReadOnly: bool
    Width: int

    def Equals(self, obj: Any) -> bool: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.TextBox: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    def GetHashCode(self) -> int: ...

class ToolBase:  # Class
    def __init__(self) -> None: ...

    Caption: str
    Category: str
    HorizontalAlignment: System.Windows.HorizontalAlignment
    ID: str
    Key: System.Windows.Input.Key
    KeyTip: str
    LargeImage: str
    MaximumSize: str
    MinWidth: float
    MinimumSize: str
    ModifierKey: System.Windows.Input.ModifierKeys
    ScriptExecute: str
    ScriptModule: str
    ScriptSetState: str
    SmallImage: str
    Style: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    Tooltip: str
    Visible: bool
    _Category: str
    _ID: str
    _Image: str

    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Build(
        self, toolManager: IToolManager, imageColor: System.Windows.Media.Color
    ) -> Any: ...
    @overload
    def Build(self, toolManager: IToolManager) -> Any: ...
    def GetCaption(self, toolManager: IToolManager, ribbon: bool) -> str: ...
    def BuildContextMenuItem(self, toolManager: IToolManager) -> Any: ...
    def BuildToolbarItem(self, toolManager: IToolManager) -> Any: ...
    @staticmethod
    def ConvertCaption(caption: str, ribbon: bool) -> str: ...
    @staticmethod
    def GetArrayHashCode(arr: List[Any]) -> int: ...
    @staticmethod
    def ObjectsAreEqual(o1: Any, o2: Any) -> bool: ...
    @staticmethod
    def StringsAreEqual(s1: str, s2: str) -> bool: ...
    def GetKeyTip(self, toolManager: IToolManager) -> str: ...
    def GetHashCode(self) -> int: ...
    @staticmethod
    def ArraysAreEqual(arr1: List[T], arr2: List[T]) -> bool: ...
    def BuildTooltip(self, toolManager: IToolManager) -> Any: ...
    @staticmethod
    def GetObjectHashCode(obj: Any) -> int: ...

class ToolbarDef(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...

    Band: int
    BandIndex: int
    Pane: str
    Tools: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase]

    def GetHashCode(self) -> int: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolbarDef: ...
    def Build(self, toolManager: IToolManager) -> PaneToolbar: ...
    def Equals(self, obj: Any) -> bool: ...

class ToolbarExtension:  # Class
    @overload
    @staticmethod
    def ConvertImage(
        image: System.Windows.Media.Imaging.BitmapSource,
        color: System.Windows.Media.Color,
    ) -> System.Windows.Media.Imaging.BitmapSource: ...
    @overload
    @staticmethod
    def ConvertImage(
        image: System.Windows.Media.Imaging.BitmapSource,
    ) -> System.Windows.Media.Imaging.BitmapSource: ...
    @overload
    @staticmethod
    def Evaluate(
        ct: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomTools,
        toolManager: IToolManager,
        instrumentType: str,
    ) -> None: ...
    @overload
    @staticmethod
    def Evaluate(
        ct: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomTools,
        toolManager: IToolManager,
        instrumentType: str,
        explorerBarPanel: System.Windows.Controls.StackPanel,
    ) -> None: ...
    @overload
    @staticmethod
    def SetButtonContent(
        button: System.Windows.Controls.Primitives.ButtonBase,
        definition: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Button,
        toolManager: IToolManager,
    ) -> None: ...
    @overload
    @staticmethod
    def SetButtonContent(
        button: System.Windows.Controls.Primitives.ButtonBase,
        definition: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.MenuDefinition,
        toolManager: IToolManager,
    ) -> None: ...
    @staticmethod
    def ToBitmapSource(
        source: System.Drawing.Bitmap,
    ) -> System.Windows.Media.Imaging.BitmapSource: ...

class Tools(
    System.IEquatable[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools]
):  # Class
    def __init__(self) -> None: ...

    ApplicationCommands: List[
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationCommand
    ]
    CategoryToolHandlers: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CategoryToolHandler
    ]
    ContextMenus: List[
        Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ContextMenu
    ]
    MouseActionMaps: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.MouseActionMap
    ]
    ToolHandlers: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolHandler
    ]
    Toolbars: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolbarDef]
    XamRibbon: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Ribbon

    @staticmethod
    def ArrayAreEqual(arr1: List[T], arr2: List[T]) -> bool: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...
    def Equals(
        self, tools: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools
    ) -> bool: ...

class WrapPanel(
    Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
):  # Class
    def __init__(self) -> None: ...

    Margin: str
    MaxRows: int
    MinRows: int
    Tools: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase]
    Vertical: bool

    def GetHashCode(self) -> int: ...
    def ShallowCopy(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.WrapPanel: ...
    def Build(self, toolManager: IToolManager) -> Any: ...
    def Equals(self, obj: Any) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import IApplicationMenu2010Content
from .OpenBatch import BrowseDataStorageViewModel, OpenBatchViewModel, OpenBatchViewType

# Stubs for namespace: Agilent.MassHunter.Quantitative.Controls.NewBatch

class BrowseDataStorageView(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class BrowseDataStorageViewModel:  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.Controls.NewBatch.NewBatchViewModel
    ) -> None: ...

    BatchFileProperty: System.Windows.DependencyProperty  # static # readonly

    AuditTrailOptionVisibility: System.Windows.Visibility  # readonly
    BatchFile: str
    NewBatchCommand: System.Windows.Input.ICommand  # readonly
    NewBatchViewModel: (
        Agilent.MassHunter.Quantitative.Controls.NewBatch.NewBatchViewModel
    )  # readonly

class NewBatchCommand(System.Windows.Input.ICommand):  # Class
    def __init__(
        self,
        browseDataStorageViewModel: Agilent.MassHunter.Quantitative.Controls.NewBatch.BrowseDataStorageViewModel,
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class NewBatchView(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    IApplicationMenu2010Content,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.Controls.NewBatch.NewBatchViewModel
    ) -> None: ...
    def InitializeComponent(self) -> None: ...
    def SetSize(self, width: float, height: float) -> None: ...

class NewBatchViewModel(OpenBatchViewModel):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    AuditTrailButtonEnabledProperty: (
        System.Windows.DependencyProperty
    )  # static # readonly
    AuditTrailOptionVisibleProperty: (
        System.Windows.DependencyProperty
    )  # static # readonly
    AuditTrailProperty: System.Windows.DependencyProperty  # static # readonly
    NewBatchButtonLabelProperty: System.Windows.DependencyProperty  # static # readonly

    AuditTrail: bool
    AuditTrailButtonEnabled: bool
    AuditTrailOptionVisible: bool
    CurrentViewType: OpenBatchViewType
    NewBatchButtonLabel: str

    def ClearNewFileName(self) -> None: ...
    def DoBrowse(self, folder: str) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")
from . import TimeUnit, XUnit

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Utilities

class ObjectXmlSerializer(Generic[T]):  # Class
    def __init__(self) -> None: ...
    def Deserialize(self, serializedObject: str) -> T: ...
    def Serialize(self, objectToSerialize: T) -> str: ...

class TimeConverter:  # Class
    @staticmethod
    def ConvertValue(
        time: float, sourceUnit: TimeUnit, targetUnit: TimeUnit
    ) -> float: ...
    @overload
    @staticmethod
    def ConvertUnit(xunit: XUnit) -> TimeUnit: ...
    @overload
    @staticmethod
    def ConvertUnit(timeUnit: TimeUnit) -> XUnit: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod

class AdductItem:  # Class
    def __init__(self, name: str) -> None: ...

    IsChecked: bool
    Name: str

class CalibrationSampleModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self) -> None: ...

    AcqDateTime: System.DateTime
    FileName: str
    IsSelected: bool
    LevelConcentration: Optional[float]
    LevelName: str
    SampleName: str

    def Clone(
        self,
    ) -> (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.CalibrationSampleModel
    ): ...

class NewMethodAcrossCalibrationsModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        window: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.NewMethodFromCalibrationsWindow,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    Adducts: List[str]
    AdductsCommand: System.Windows.Input.ICommand  # readonly
    AdductsStr: str
    BatchPath: str
    BatchPathCommand: System.Windows.Input.ICommand  # readonly
    CalibrationSamples: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.CalibrationSampleModel
    ]
    CalibrationSamplesCommand: System.Windows.Input.ICommand  # readonly
    DestinationMethodName: str
    ImportBatchCommand: System.Windows.Input.ICommand  # readonly
    LibraryPath: str
    NumberOfQualifiers: int
    NumberOfSelectedCalibrationSamples: str  # readonly
    NumberOfSelectedTargetCompounds: str  # readonly
    ReferenceLibraryCommand: System.Windows.Input.ICommand  # readonly
    TargetCompounds: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.TargetCompoundModel
    ]
    TargetCompoundsCommand: System.Windows.Input.ICommand  # readonly

    def _CreateMethod(
        self,
        dlg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs2.ProgressDialog,
    ) -> bool: ...
    def SetBatchFolder(self, batchFolder: str) -> None: ...
    def ValidateTargetCompounds(
        self,
        compounds: List[
            Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.TargetCompoundModel
        ],
    ) -> None: ...
    def CreateMethod(self) -> bool: ...
    def ValidateCalibrationSamples(
        self,
        samples: List[
            Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.CalibrationSampleModel
        ],
    ) -> None: ...

class NewMethodFromCalibrationsWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class SelectAdductsModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self) -> None: ...

    Items: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.AdductItem
    ]  # readonly
    SelectedAdducts: List[str]

class SelectAdductsWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class SelectCalibrationsModel:  # Class
    def __init__(
        self,
        calibrations: List[
            Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.CalibrationSampleModel
        ],
    ) -> None: ...

    CalibrationSamples: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.CalibrationSampleModel
    ]

class SelectCalibrationsWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...

class TargetCompoundModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(self) -> None: ...

    CAS: str
    CompoundName: str
    Formula: str
    IsSelected: bool
    RetentionTime: Optional[float]

    def Clone(
        self,
    ) -> (
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.TargetCompoundModel
    ): ...

class TargetCompoundsModel(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        window: Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.TargetCompoundsWindow,
        compounds: List[
            Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.TargetCompoundModel
        ],
    ) -> None: ...

    CommandAdd: System.Windows.Input.ICommand  # readonly
    CommandDelete: System.Windows.Input.ICommand  # readonly
    CommandImportLibrary: System.Windows.Input.ICommand  # readonly
    CommandOK: System.Windows.Input.ICommand  # readonly
    CommandSelectAll: System.Windows.Input.ICommand  # readonly
    TargetCompounds: List[
        Agilent.MassHunter.Quantitative.DynamicCalibrationSetup.NewMethod.TargetCompoundModel
    ]

class TargetCompoundsWindow(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Window,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IWindowService,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import IBlankHits, IReportProgress, SampleRowID
from .Command import CommandContext
from .Utils import LibraryMzValues

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Analysis

class AnalysisTaskScheduler(System.Threading.Tasks.TaskScheduler):  # Class
    def __init__(self) -> None: ...

    MaximumConcurrencyLevel: int  # readonly

class AnalyzeSample(IReportProgress):  # Class
    def __init__(
        self,
        context: CommandContext,
        abort: System.Threading.ManualResetEvent,
        batchID: int,
        sampleID: int,
        reanalyze: bool,
        libraryMzValues: LibraryMzValues,
        blankHits: IBlankHits,
        taskScheduler: System.Threading.Tasks.TaskScheduler,
    ) -> None: ...

    SampleRowID: SampleRowID  # readonly

    def ClearProgress(self) -> None: ...
    def ClearTargetMatchResults(self) -> None: ...
    @overload
    def Identify(self, result: System.IAsyncResult) -> None: ...
    @overload
    def Identify(self) -> None: ...
    def FinishProgress(self) -> None: ...
    def ClearDeconvolutionResults(self) -> None: ...
    def ClearBlankSubtraction(self) -> None: ...
    @staticmethod
    def IsBlank(sampleType: str) -> bool: ...
    @overload
    def TargetMatch(self, result: System.IAsyncResult) -> None: ...
    @overload
    def TargetMatch(self) -> None: ...
    def ClearIdentificationResults(self) -> None: ...
    @overload
    def Deconvolute(self, result: System.IAsyncResult) -> None: ...
    @overload
    def Deconvolute(self) -> None: ...
    def ReportProgress(self, totalSteps: int, currentStep: int) -> None: ...
    @overload
    def BlankSubtract(self, tasks: List[System.Threading.Tasks.Task[None]]) -> None: ...
    @overload
    def BlankSubtract(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import QuantDataProvider
from .Compliance import ICompliance, IImpersonationContext
from .ScriptEngine import IronEngine

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript

class GraphicsRange:  # Struct
    def __init__(self, min: float, max: float) -> None: ...

    Max: float  # readonly
    Min: float  # readonly

class IFixedGraphics(object):  # Interface
    def GetSampleRangeX(
        self, sampleName: str
    ) -> Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ]: ...
    def GetSampleRangeY(
        self, sampleName: str
    ) -> Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ]: ...
    def GetCompoundRangeMz(
        self, compoundName: str
    ) -> Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ]: ...
    def GetCompoundRangeX(
        self, compoundName: str
    ) -> Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ]: ...
    def GetCompoundRangeY(
        self, compoundName: str
    ) -> Optional[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.GraphicsRange
    ]: ...

class IImpersonateContext(System.IDisposable):  # Interface
    ...

class IReportCompliance(object):  # Interface
    ComplianceDisplayName: str  # readonly
    ComplianceName: str  # readonly
    Server: str  # readonly
    UserName: str  # readonly

    def TranslateToLocalPath(self, pathName: str) -> str: ...
    def Impersonate(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IImpersonateContext
    ): ...

class IReportContext(object):  # Interface
    ComplianceDisplayName: str  # readonly
    ComplianceName: str  # readonly
    ComplianceServer: str  # readonly
    OutputPath: str
    PreferredPageSize: str
    UserName: str  # readonly

    def CreateReportPlot(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlot
    ): ...

class IReportDataProvider(object):  # Interface
    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportCompliance
    )  # readonly
    CurrentVersion: str  # readonly
    FixedGraphics: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IFixedGraphics
    )
    MethodPath: str
    ReportContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportContext
    )  # readonly
    TemplatePath: str

    def ProgressMessage(self, pageNumber: int, message: str) -> None: ...
    def CheckAbortSignal(self) -> None: ...
    def FormatNumber(self, columnName: str, value_: float) -> str: ...
    def IsAttemptingAbort(self) -> bool: ...
    def FormatDateTime(self, columnName: str, value_: System.DateTime) -> str: ...
    def TranslateEnumValue(
        self, tableName: str, columnName: str, value_: str
    ) -> str: ...
    def GetNumberFormat(self, columnName: str) -> str: ...

class IReportPlot(object):  # Interface
    BottomAxisTitle: str
    LeftAxisTitle: str
    MaxX: float
    MaxY: float
    MinX: float
    MinY: float
    Title: str

    def ClearSeries(self) -> None: ...
    def AutoScale(self) -> None: ...
    def AddSeries(
        self,
        series: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlotSeries,
    ) -> None: ...
    def Draw(
        self, writer: iTextSharp.text.pdf.PdfWriter, width: float, height: float
    ) -> iTextSharp.text.Image: ...
    def CreateSeries(
        self, data: Any
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlotSeries
    ): ...

class IReportPlotSeries(object):  # Interface
    _Series: Any  # readonly

    @overload
    def Normalize(self, max: float) -> None: ...
    @overload
    def Normalize(self, min: float, max: float) -> None: ...

class IReportScript(System.IDisposable):  # Interface
    DataProvider: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportDataProvider
    )
    PreferredPageSize: str

    def Process(self, file: str) -> None: ...

class ImpersonationContext(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IImpersonateContext,
    System.IDisposable,
):  # Class
    def __init__(self, ictx: IImpersonationContext) -> None: ...
    def Dispose(self) -> None: ...

class ProviderOption:  # Class
    def __init__(self) -> None: ...

    Name: str
    Value: str

class ReportCompliance(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportCompliance
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

    ComplianceDisplayName: str  # readonly
    ComplianceName: str  # readonly
    Server: str  # readonly
    UserName: str  # readonly

    def TranslateToLocalPath(self, pathName: str) -> str: ...
    def Impersonate(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IImpersonateContext
    ): ...

class ReportContext(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportContext
):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

    ComplianceDisplayName: str  # readonly
    ComplianceName: str  # readonly
    ComplianceServer: str  # readonly
    OutputPath: str
    PreferredPageSize: str
    UserName: str  # readonly

    def CreateReportPlot(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlot
    ): ...

class ReportDefinition:  # Class
    def __init__(self) -> None: ...

    Codes: List[str]
    Copyright: str
    Cultures: List[str]
    Debug: bool
    Language: str
    PageSizes: List[str]
    ProviderOptions: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.ProviderOption
    ]
    PublishFormats: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.ReportPublishFormat
    ]
    References: List[str]
    Type: str

class ReportPlot(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlot
):  # Class
    def __init__(self) -> None: ...

    BottomAxisTitle: str
    LeftAxisTitle: str
    MaxX: float
    MaxY: float
    MinX: float
    MinY: float
    Title: str

    def ClearSeries(self) -> None: ...
    def AutoScale(self) -> None: ...
    def AddSeries(
        self,
        series: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlotSeries,
    ) -> None: ...
    def Draw(
        self, writer: iTextSharp.text.pdf.PdfWriter, width: float, height: float
    ) -> iTextSharp.text.Image: ...
    def CreateSeries(
        self, data: Any
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlotSeries
    ): ...

class ReportPlotSeries(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportPlotSeries
):  # Class
    def __init__(
        self, fxdata: Agilent.MassSpectrometry.DataAnalysis.IFXData
    ) -> None: ...

    _Series: Any  # readonly

    @overload
    def Normalize(self, min: float, max: float) -> None: ...
    @overload
    def Normalize(self, max: float) -> None: ...

class ReportPublishFormat:  # Class
    def __init__(self) -> None: ...

    Extension: str
    Name: str

class ReportScriptEngine:  # Class
    FilesToClean: List[str]  # static # readonly

    @staticmethod
    def CreateReportScript(
        pathName: str,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportScript
    ): ...
    @staticmethod
    def LoadTemplate(
        pathName: str,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.ReportDefinition
    ): ...

class ReportScriptException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, ex: System.Exception) -> None: ...

class ReportScriptPython(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportScript,
):  # Class
    def __init__(self) -> None: ...

    AbortHandleName: str
    DataProvider: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportDataProvider
    )
    Files: List[str]
    PreferredPageSize: str
    ReportContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportScript.IReportContext
    )
    ResourceAssemblyPath: str

    @staticmethod
    def GetDebugEngine() -> IronEngine: ...
    def Process(self, file: str) -> None: ...
    def Dispose(self) -> None: ...
    @staticmethod
    def SetDebugEngine(debugEngine: IronEngine) -> None: ...

class Utils:  # Class
    @staticmethod
    def GetDefaultPageSize(
        ci: System.Globalization.CultureInfo,
    ) -> iTextSharp.text.Rectangle: ...
    @staticmethod
    def GetPageSize(name: str) -> iTextSharp.text.Rectangle: ...
    @staticmethod
    def ProgressMessage(pageNumber: int, message: str) -> None: ...
    @staticmethod
    def DrawImage(
        writer: iTextSharp.text.pdf.PdfWriter,
        width: float,
        height: float,
        d: System.Action[Agilent.MassHunter.Quantitative.PlotControl.IGraphics],
    ) -> iTextSharp.text.Image: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Configurations

class ApplicationSettings(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    AutoSortRows: int  # readonly
    CommandLog: str  # readonly
    CommandLogLanguage: str  # readonly
    DumpLogOnNormalExit: bool  # readonly
    ErrorReportingEmailAddress: str  # readonly
    ErrorReportingEnabled: bool  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Configurations.ApplicationSettings
    )  # static # readonly
    MaxCompoundsToCopy: int  # readonly
    MaxVisibleSpectra: int  # readonly
    Multithreading: bool  # readonly
    PrecursorBinWidth: float  # readonly
    PrecursorFillColor: System.Drawing.Color  # readonly
    PrecursorLineColor: System.Drawing.Color  # readonly
    PrecursorSize: int  # readonly

class Config:  # Class
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Configurations.Config
    )  # static # readonly

    def Save(self) -> None: ...

class ConfigElement(System.Configuration.ConfigurationElement, Generic[T]):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, value_: T) -> None: ...

    Value: T

class Formats:  # Class
    Abundance: str
    AccurateMz: str
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Configurations.Formats
    )  # static # readonly
    def __getitem__(self, key: str) -> str: ...
    def __setitem__(self, key: str, value_: str) -> None: ...
    UnitMz: str

class UISettings(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    DefaultVisibleColumns: str  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Configurations.UISettings
    )  # static # readonly

class UserSettings(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Configurations.UserSettings
    )  # static # readonly
